#
# Copyright (c) 2022, NVIDIA CORPORATION.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
try:
    from numba import cuda

except ImportError:
    cuda = None

HAS_GPU = False
try:
    from dask.distributed.diagnostics import nvml

    HAS_GPU = nvml.device_get_count() > 0
except ImportError:
    # We can use `cuda` to set `HAS_GPU` now that we
    # know `distributed` is not installed (otherwise
    # the `nvml` import would have succeeded)
    HAS_GPU = cuda is not None
